diff --git a/dumux/boxmodels/1p/1ppropertydefaults.hh b/dumux/boxmodels/1p/1ppropertydefaults.hh
index 56b4fa4f9968233e22681120af60ec38c34035ac..3d6e0132127cd2181c761f81072acc1939fca403 100644
--- a/dumux/boxmodels/1p/1ppropertydefaults.hh
+++ b/dumux/boxmodels/1p/1ppropertydefaults.hh
@@ -76,6 +76,9 @@ SET_TYPE_PROP(BoxOneP, Indices, OnePIndices);
 //! DEPRECATED OnePIndices property
 SET_TYPE_PROP(BoxOneP, OnePIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxOneP, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
+
 //! The weight of the upwind control volume when calculating
 //! fluxes. Use central differences by default.
 SET_SCALAR_PROP(BoxOneP, UpwindWeight, 0.5);
diff --git a/dumux/boxmodels/1p2c/1p2cpropertydefaults.hh b/dumux/boxmodels/1p2c/1p2cpropertydefaults.hh
index 599f9d950fbd2b199e0510a17e1d32cbf8d18c09..0b8157e9f7ebdef3c47c34baf2d0b46e710be58e 100644
--- a/dumux/boxmodels/1p2c/1p2cpropertydefaults.hh
+++ b/dumux/boxmodels/1p2c/1p2cpropertydefaults.hh
@@ -77,6 +77,9 @@ SET_TYPE_PROP(BoxOnePTwoC, Indices, Dumux::OnePTwoCIndices<0>);
 
 //! DEPRECATED OnePTwoCIndices property
 SET_TYPE_PROP(BoxOnePTwoC, OnePTwoCIndices, typename GET_PROP_TYPE(TypeTag, Indices));
+
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxOnePTwoC, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
 }
 // \}
 }
diff --git a/dumux/boxmodels/2p/2ppropertydefaults.hh b/dumux/boxmodels/2p/2ppropertydefaults.hh
index c4d56da0236b31371c20e1cdd4711f4045ff8df1..6f6b2a3e5789ae2bd4aa0eae064e8e45bab40785 100644
--- a/dumux/boxmodels/2p/2ppropertydefaults.hh
+++ b/dumux/boxmodels/2p/2ppropertydefaults.hh
@@ -86,6 +86,9 @@ SET_TYPE_PROP(BoxTwoP,
 //! DEPRECATED TwoPIndices property
 SET_TYPE_PROP(BoxTwoP, TwoPIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxTwoP, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
+
 /*!
  * \brief Set the property for the material parameters by extracting
  *        it from the material law.
diff --git a/dumux/boxmodels/2p2c/2p2cfluxvariables.hh b/dumux/boxmodels/2p2c/2p2cfluxvariables.hh
index 1d6eb361d63bcfb038e3603bf5c09165a23f2079..aa00c92ff240d9a23421bc1e5f5c7c9d391cd0e0 100644
--- a/dumux/boxmodels/2p2c/2p2cfluxvariables.hh
+++ b/dumux/boxmodels/2p2c/2p2cfluxvariables.hh
@@ -55,15 +55,15 @@ class TwoPTwoCFluxVariables
     typedef typename GET_PROP_TYPE(TypeTag, Problem) Problem;
     typedef typename GET_PROP_TYPE(TypeTag, VolumeVariables) VolumeVariables;
     typedef typename GET_PROP_TYPE(TypeTag, ElementVolumeVariables) ElementVolumeVariables;
-    typedef typename GET_PROP_TYPE(TypeTag, SpatialParameters) SpatialParameters;
+    typedef typename GET_PROP_TYPE(TypeTag, SpatialParams) SpatialParams;
     enum { numPhases = GET_PROP_VALUE(TypeTag, NumPhases) };
 
     typedef typename GET_PROP_TYPE(TypeTag, Indices) Indices;
     enum {
-        lPhaseIdx = Indices::lPhaseIdx,
-        gPhaseIdx = Indices::gPhaseIdx,
-        lCompIdx = Indices::lCompIdx,
-        gCompIdx = Indices::gCompIdx
+        wPhaseIdx = Indices::lPhaseIdx,
+        nPhaseIdx = Indices::gPhaseIdx,
+        wCompIdx = Indices::lCompIdx,
+        nCompIdx = Indices::gCompIdx
     };
 
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
@@ -71,8 +71,8 @@ class TwoPTwoCFluxVariables
     enum { dim = GridView::dimension };
 
     typedef typename GET_PROP_TYPE(TypeTag, Scalar) Scalar;
-    typedef Dune::FieldVector<Scalar, dim> Vector;
-    typedef Dune::FieldMatrix<Scalar, dim, dim> Tensor;
+    typedef Dune::FieldVector<Scalar, dim> DimVector;
+    typedef Dune::FieldMatrix<Scalar, dim, dim> DimMatrix;
 
     typedef typename GET_PROP_TYPE(TypeTag, FVElementGeometry) FVElementGeometry;
     typedef typename FVElementGeometry::SubControlVolumeFace SCVFace;
@@ -83,25 +83,25 @@ public:
      *
      * \param problem The problem
      * \param element The finite element
-     * \param elemGeom The finite-volume geometry in the box scheme
+     * \param fvGeometry The finite-volume geometry in the box scheme
      * \param faceIdx The local index of the SCV (sub-control-volume) face
      * \param elemVolVars The volume variables of the current element
      * \param onBoundary Distinguishes if we are on a SCV face or on a boundary face
      */
     TwoPTwoCFluxVariables(const Problem &problem,
                           const Element &element,
-                          const FVElementGeometry &elemGeom,
-                          int faceIdx,
+                          const FVElementGeometry &fvGeometry,
+                          const int faceIdx,
                           const ElementVolumeVariables &elemVolVars,
-                          bool onBoundary = false)
-        : fvGeom_(elemGeom), faceIdx_(faceIdx), onBoundary_(onBoundary)
+                          const bool onBoundary = false)
+        : fvGeometry_(fvGeometry), faceIdx_(faceIdx), onBoundary_(onBoundary)
     {
         for (int phaseIdx = 0; phaseIdx < numPhases; ++phaseIdx) {
-            densityAtIP_[phaseIdx] = Scalar(0);
-            molarDensityAtIP_[phaseIdx] = Scalar(0);
+            density_[phaseIdx] = Scalar(0);
+            molarDensity_[phaseIdx] = Scalar(0);
             potentialGrad_[phaseIdx] = Scalar(0);
-            concentrationGrad_[phaseIdx] = Scalar(0);
-            molarConcGrad_[phaseIdx] = Scalar(0);
+            massFractionGrad_[phaseIdx] = Scalar(0);
+            moleFractionGrad_[phaseIdx] = Scalar(0);
         }
 
         calculateValues_(problem, element, elemVolVars);
@@ -113,23 +113,23 @@ protected:
                           const ElementVolumeVariables &elemVolVars)
     {
         // calculate densities at the integration points of the face
-        Vector tmp(0.0);
+        DimVector tmp(0.0);
         for (int idx = 0;
-             idx < fvGeom_.numVertices;
+             idx < fvGeometry_.numVertices;
              idx++) // loop over adjacent vertices
         {
             for (int phaseIdx = 0; phaseIdx < numPhases; phaseIdx++)
             {
-               densityAtIP_[phaseIdx] += elemVolVars[idx].density(phaseIdx)*
+               density_[phaseIdx] += elemVolVars[idx].density(phaseIdx)*
                        face().shapeValue[idx];
-               molarDensityAtIP_[phaseIdx] += elemVolVars[idx].molarDensity(phaseIdx)*
+               molarDensity_[phaseIdx] += elemVolVars[idx].molarDensity(phaseIdx)*
                        face().shapeValue[idx];
             }
         }
 
         calculateGradients_(problem, element, elemVolVars);
         calculateVelocities_(problem, element, elemVolVars);
-        calculateDiffCoeffPM_(problem, element, elemVolVars);
+        calculatePorousDiffCoeff_(problem, element, elemVolVars);
     }
 
     void calculateGradients_(const Problem &problem,
@@ -137,13 +137,13 @@ protected:
                              const ElementVolumeVariables &elemVolVars)
     {
         // calculate gradients
-        Vector tmp(0.0);
+        DimVector tmp(0.0);
         for (int idx = 0;
-             idx < fvGeom_.numVertices;
+             idx < fvGeometry_.numVertices;
              idx++) // loop over adjacent vertices
         {
             // FE gradient at vertex idx
-            const Vector &feGrad = face().grad[idx];
+            const DimVector &feGrad = face().grad[idx];
 
             // compute sum of pressure gradients for each phase
             for (int phaseIdx = 0; phaseIdx < numPhases; phaseIdx++)
@@ -157,22 +157,22 @@ protected:
             // the concentration gradient of the non-wetting
             // component in the wetting phase
             tmp = feGrad;
-            tmp *= elemVolVars[idx].fluidState().massFraction(lPhaseIdx, gCompIdx);
-            concentrationGrad_[lPhaseIdx] += tmp;
+            tmp *= elemVolVars[idx].fluidState().massFraction(wPhaseIdx, nCompIdx);
+            massFractionGrad_[wPhaseIdx] += tmp;
 
             tmp = feGrad;
-            tmp *= elemVolVars[idx].fluidState().moleFraction(lPhaseIdx, gCompIdx);
-            molarConcGrad_[lPhaseIdx] += tmp;
+            tmp *= elemVolVars[idx].fluidState().moleFraction(wPhaseIdx, nCompIdx);
+            moleFractionGrad_[wPhaseIdx] += tmp;
 
             //            // the concentration gradient of the wetting component
             //            // in the non-wetting phase
             tmp = feGrad;
-            tmp *= elemVolVars[idx].fluidState().massFraction(gPhaseIdx, lCompIdx);
-            concentrationGrad_[gPhaseIdx] += tmp;
+            tmp *= elemVolVars[idx].fluidState().massFraction(nPhaseIdx, wCompIdx);
+            massFractionGrad_[nPhaseIdx] += tmp;
 
             tmp = feGrad;
-            tmp *= elemVolVars[idx].fluidState().moleFraction(gPhaseIdx, lCompIdx);
-            molarConcGrad_[gPhaseIdx] += tmp;
+            tmp *= elemVolVars[idx].fluidState().moleFraction(nPhaseIdx, wCompIdx);
+            moleFractionGrad_[nPhaseIdx] += tmp;
         }
 
         ///////////////
@@ -181,8 +181,8 @@ protected:
         if (GET_PARAM(TypeTag, bool, EnableGravity)) {
             // estimate the gravitational acceleration at a given SCV face
             // using the arithmetic mean
-            Vector g(problem.boxGravity(element, fvGeom_, face().i));
-            g += problem.boxGravity(element, fvGeom_, face().j);
+            DimVector g(problem.boxGravity(element, fvGeometry_, face().i));
+            g += problem.boxGravity(element, fvGeometry_, face().j);
             g /= 2;
 
             for (int phaseIdx=0; phaseIdx < numPhases; phaseIdx++)
@@ -202,7 +202,7 @@ protected:
                 Scalar density = (fI*rhoI + fJ*rhoJ)/(fI + fJ);
 
                 // make gravity acceleration a force
-                Vector f(g);
+                DimVector f(g);
                 f *= density;
 
                 // calculate the final potential gradient
@@ -230,17 +230,17 @@ protected:
                               const Element &element,
                               const ElementVolumeVariables &elemVolVars)
     {
-        const SpatialParameters &spatialParams = problem.spatialParameters();
+        const SpatialParams &spatialParams = problem.spatialParams();
         // multiply the pressure potential by the intrinsic permeability
-        Tensor K;
+        DimMatrix K;
         for (int phaseIdx=0; phaseIdx < numPhases; phaseIdx++)
         {
             spatialParams.meanK(K,
                                 spatialParams.intrinsicPermeability(element,
-                                                                    fvGeom_,
+                                                                    fvGeometry_,
                                                                     face().i),
                                 spatialParams.intrinsicPermeability(element,
-                                                                    fvGeom_,
+                                                                    fvGeometry_,
                                                                     face().j));
             K.mv(potentialGrad_[phaseIdx], Kmvp_[phaseIdx]);
             KmvpNormal_[phaseIdx] = -(Kmvp_[phaseIdx]*face().normal);
@@ -259,19 +259,19 @@ protected:
         }
     }
 
-    void calculateDiffCoeffPM_(const Problem &problem,
+    void calculatePorousDiffCoeff_(const Problem &problem,
                                const Element &element,
                                const ElementVolumeVariables &elemVolVars)
     {
-        const VolumeVariables &vDat_i = elemVolVars[face().i];
-        const VolumeVariables &vDat_j = elemVolVars[face().j];
+        const VolumeVariables &volVarsI = elemVolVars[face().i];
+        const VolumeVariables &volVarsJ = elemVolVars[face().j];
 
         for (int phaseIdx = 0; phaseIdx < numPhases; ++phaseIdx)
         {
             // make sure to only calculate diffusion coefficients
             // for phases which exist in both finite volumes
-            if (vDat_i.saturation(phaseIdx) <= 0 ||
-                vDat_j.saturation(phaseIdx) <= 0)
+            if (volVarsI.saturation(phaseIdx) <= 0 ||
+                volVarsJ.saturation(phaseIdx) <= 0)
             {
                 porousDiffCoeff_[phaseIdx] = 0.0;
                 continue;
@@ -279,17 +279,17 @@ protected:
 
             // calculate tortuosity at the nodes i and j needed
             // for porous media diffusion coefficient
-            Scalar tau_i =
-                1.0/(vDat_i.porosity() * vDat_i.porosity()) *
-                pow(vDat_i.porosity() * vDat_i.saturation(phaseIdx), 7.0/3);
-            Scalar tau_j =
-                1.0/(vDat_j.porosity() * vDat_j.porosity()) *
-                pow(vDat_j.porosity() * vDat_j.saturation(phaseIdx), 7.0/3);
+            Scalar tauI =
+                1.0/(volVarsI.porosity() * volVarsI.porosity()) *
+                pow(volVarsI.porosity() * volVarsI.saturation(phaseIdx), 7.0/3);
+            Scalar tauJ =
+                1.0/(volVarsJ.porosity() * volVarsJ.porosity()) *
+                pow(volVarsJ.porosity() * volVarsJ.saturation(phaseIdx), 7.0/3);
             // Diffusion coefficient in the porous medium
 
             // -> harmonic mean
-            porousDiffCoeff_[phaseIdx] = harmonicMean(vDat_i.porosity() * vDat_i.saturation(phaseIdx) * tau_i * vDat_i.diffCoeff(phaseIdx),
-                                                      vDat_j.porosity() * vDat_j.saturation(phaseIdx) * tau_j * vDat_j.diffCoeff(phaseIdx));
+            porousDiffCoeff_[phaseIdx] = harmonicMean(volVarsI.porosity() * volVarsI.saturation(phaseIdx) * tauI * volVarsI.diffCoeff(phaseIdx),
+                                                      volVarsJ.porosity() * volVarsJ.saturation(phaseIdx) * tauJ * volVarsJ.diffCoeff(phaseIdx));
         }
     }
 
@@ -313,7 +313,7 @@ public:
      * \brief Return the pressure potential multiplied with the
      *        intrinsic permeability as vector (for velocity output)
      */
-    Vector Kmvp(int phaseIdx) const
+    DimVector Kmvp(int phaseIdx) const
     { return Kmvp_[phaseIdx]; }
 
     /*!
@@ -340,27 +340,56 @@ public:
      * \brief Return density \f$\mathrm{[kg/m^3]}\f$ of a phase at the integration
      *        point.
      */
+    DUMUX_DEPRECATED_MSG("use density instead")
     Scalar densityAtIP(int phaseIdx) const
-    { return densityAtIP_[phaseIdx]; }
+    { return density(phaseIdx); }
+
+    /*!
+     * \brief Return density \f$\mathrm{[kg/m^3]}\f$ of a phase.
+     */
+    Scalar density(int phaseIdx) const
+    { return density_[phaseIdx]; }
 
     /*!
      * \brief Return molar density \f$\mathrm{[mol/m^3]}\f$ of a phase at the integration
      *        point.
      */
+    DUMUX_DEPRECATED_MSG("use molarDensity instead")
     Scalar molarDensityAtIP(int phaseIdx) const
-    { return molarDensityAtIP_[phaseIdx]; }
+    { return molarDensity(phaseIdx); }
+
+    /*!
+     * \brief Return molar density \f$\mathrm{[mol/m^3]}\f$ of a phase.
+     */
+    Scalar molarDensity(int phaseIdx) const
+    { return molarDensity_[phaseIdx]; }
 
     /*!
      * \brief The concentration gradient of a component in a phase.
      */
-    const Vector &concentrationGrad(int phaseIdx) const
-    { return concentrationGrad_[phaseIdx]; };
+    DUMUX_DEPRECATED_MSG("use massFractionGrad instead")
+    const DimVector &concentrationGrad(int phaseIdx) const
+    { return massFractionGrad(phaseIdx); };
+
+    /*!
+     * \brief The mass fraction gradient of the dissolved component in a phase.
+     */
+    DUMUX_DEPRECATED_MSG("use moleFractionGrad instead")
+    const DimVector &massFractionGrad(int phaseIdx) const
+    { return massFractionGrad_[phaseIdx]; };
 
     /*!
      * \brief The molar concentration gradient of a component in a phase.
      */
-    const Vector &molarConcGrad(int phaseIdx) const
-    { return molarConcGrad_[phaseIdx]; };
+    DUMUX_DEPRECATED_MSG("use moleFractionGrad instead")
+    const DimVector &molarConcGrad(int phaseIdx) const
+    { return moleFractionGrad(phaseIdx); };
+
+    /*!
+     * \brief The mole fraction gradient of the dissolved component in a phase.
+     */
+    const DimVector &moleFractionGrad(int phaseIdx) const
+    { return moleFractionGrad_[phaseIdx]; };
 
     /*!
      * \brief The face of the current sub-control volume. This may be either
@@ -369,26 +398,26 @@ public:
     const SCVFace &face() const
     {
         if (onBoundary_)
-            return fvGeom_.boundaryFace[faceIdx_];
+            return fvGeometry_.boundaryFace[faceIdx_];
         else
-            return fvGeom_.subContVolFace[faceIdx_];
+            return fvGeometry_.subContVolFace[faceIdx_];
     }
 
 protected:
-    const FVElementGeometry &fvGeom_;
+    const FVElementGeometry &fvGeometry_;
     const int faceIdx_;
     const bool onBoundary_;
 
     // gradients
-    Vector potentialGrad_[numPhases];
-    Vector concentrationGrad_[numPhases];
-    Vector molarConcGrad_[numPhases];
+    DimVector potentialGrad_[numPhases];
+    DimVector massFractionGrad_[numPhases];
+    DimVector moleFractionGrad_[numPhases];
 
     // density of each face at the integration point
-    Scalar densityAtIP_[numPhases], molarDensityAtIP_[numPhases];
+    Scalar density_[numPhases], molarDensity_[numPhases];
 
     // intrinsic permeability times pressure potential gradient
-    Vector Kmvp_[numPhases];
+    DimVector Kmvp_[numPhases];
     // projected on the face normal
     Scalar KmvpNormal_[numPhases];
 
diff --git a/dumux/boxmodels/2p2c/2p2cproperties.hh b/dumux/boxmodels/2p2c/2p2cproperties.hh
index 7480b0a8fde89558d8e6a82b9dbcbe84738a5d50..e865f4b8225e7b40d4a3bf2bb5844ca917e9bbfb 100644
--- a/dumux/boxmodels/2p2c/2p2cproperties.hh
+++ b/dumux/boxmodels/2p2c/2p2cproperties.hh
@@ -58,7 +58,8 @@ NEW_PROP_TAG(NumComponents); //!< Number of fluid components in the system
 NEW_PROP_TAG(TwoPTwoCIndices); //!< DEPRECATED Enumerations for the 2p2c models
 NEW_PROP_TAG(Indices); //!< Enumerations for the model
 NEW_PROP_TAG(Formulation);   //!< The formulation of the model
-NEW_PROP_TAG(SpatialParameters); //!< The type of the spatial parameters
+NEW_PROP_TAG(SpatialParams); //!< The type of the spatial parameters
+NEW_PROP_TAG(SpatialParameters); //!< DEPRECATED The type of the spatial parameters
 NEW_PROP_TAG(FluidSystem); //!< Type of the multi-component relations
 
 NEW_PROP_TAG(MaterialLaw);   //!< The material law which ought to be used (extracted from the spatial parameters)
diff --git a/dumux/boxmodels/2p2c/2p2cpropertydefaults.hh b/dumux/boxmodels/2p2c/2p2cpropertydefaults.hh
index 64381ac65abea5fed3d77fc0d7557c21f10e2e8c..31a1f49ca4e1d67f2f31a1b56b915a00fe939cbb 100644
--- a/dumux/boxmodels/2p2c/2p2cpropertydefaults.hh
+++ b/dumux/boxmodels/2p2c/2p2cpropertydefaults.hh
@@ -139,6 +139,9 @@ SET_PROP(BoxTwoPTwoC,
 //! DEPRECATED TwoPTwoCIndices property
 SET_TYPE_PROP(BoxTwoPTwoC, TwoPTwoCIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxTwoPTwoC, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
+
 // disable velocity output by default
 SET_BOOL_PROP(BoxTwoPTwoC, EnableVelocityOutput, false);
 
diff --git a/dumux/boxmodels/2p2cni/2p2cnipropertydefaults.hh b/dumux/boxmodels/2p2cni/2p2cnipropertydefaults.hh
index 15fbcf0b66eaf7e886608abca5a57dbec8f9be68..363d436131a47a588567f0210b613e65c1f896f6 100644
--- a/dumux/boxmodels/2p2cni/2p2cnipropertydefaults.hh
+++ b/dumux/boxmodels/2p2cni/2p2cnipropertydefaults.hh
@@ -81,6 +81,10 @@ public:
 SET_TYPE_PROP(BoxTwoPTwoCNI, TwoPTwoCIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 SET_TYPE_PROP(BoxTwoPTwoCNI, TwoPTwoCNIIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 
+
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxTwoPTwoCNI, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
+
 }
 
 }
diff --git a/dumux/boxmodels/3p3c/3p3cpropertydefaults.hh b/dumux/boxmodels/3p3c/3p3cpropertydefaults.hh
index 73f4134e0a2143d90a47ffb0ca0900810ddf0879..0493d25f7a11369eeb3a4e344046fb58e6ba1c45 100644
--- a/dumux/boxmodels/3p3c/3p3cpropertydefaults.hh
+++ b/dumux/boxmodels/3p3c/3p3cpropertydefaults.hh
@@ -119,6 +119,9 @@ SET_TYPE_PROP(BoxThreePThreeC, Indices, ThreePThreeCIndices<TypeTag, /*PVOffset=
 
 //! DEPRECATED ThreePThreeCIndices property
 SET_TYPE_PROP(BoxThreePThreeC, ThreePThreeCIndices, typename GET_PROP_TYPE(TypeTag, Indices));
+
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxThreePThreeC, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
 }
 
 }
diff --git a/dumux/boxmodels/3p3cni/3p3cnipropertydefaults.hh b/dumux/boxmodels/3p3cni/3p3cnipropertydefaults.hh
index d65f31368f4489b53e9c314b34ebb368f07d50bd..91abfd839e9aff11ca894c2d6698eefe4aab6d10 100644
--- a/dumux/boxmodels/3p3cni/3p3cnipropertydefaults.hh
+++ b/dumux/boxmodels/3p3cni/3p3cnipropertydefaults.hh
@@ -77,6 +77,9 @@ SET_TYPE_PROP(BoxThreePThreeCNI, Indices, ThreePThreeCNIIndices<TypeTag, 0>);
 SET_TYPE_PROP(BoxThreePThreeCNI, ThreePThreeCIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 SET_TYPE_PROP(BoxThreePThreeCNI, ThreePThreeCNIIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxThreePThreeCNI, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
+
 }
 
 }
diff --git a/dumux/boxmodels/richards/richardspropertydefaults.hh b/dumux/boxmodels/richards/richardspropertydefaults.hh
index d2771be793e5861a9c8bd0fcf3457f3bb06b0d1a..cd757ed928fcae780d7fe30fbed5426d97da9082 100644
--- a/dumux/boxmodels/richards/richardspropertydefaults.hh
+++ b/dumux/boxmodels/richards/richardspropertydefaults.hh
@@ -83,6 +83,9 @@ SET_TYPE_PROP(BoxRichards, Indices, Dumux::RichardsIndices);
 //! DEPRECATED RichardsIndices property
 SET_TYPE_PROP(BoxRichards, RichardsIndices, typename GET_PROP_TYPE(TypeTag, Indices));
 
+//! DEPRECATED SpatialParameters property
+SET_TYPE_PROP(BoxRichards, SpatialParameters, typename GET_PROP_TYPE(TypeTag, SpatialParams));
+
 /*!
  * \brief Set type of the parameter objects for the material law
  *
diff --git a/test/boxmodels/1p/1ptestproblem.hh b/test/boxmodels/1p/1ptestproblem.hh
index d614d869da6629dbe9221c57f957beec14629f8a..ae0beb1f4330c00127e0ad48882a0b8802f914bd 100644
--- a/test/boxmodels/1p/1ptestproblem.hh
+++ b/test/boxmodels/1p/1ptestproblem.hh
@@ -77,7 +77,7 @@ SET_PROP(OnePTestProblem, Problem)
 { typedef Dumux::OnePTestProblem<TypeTag> type; };
 
 // Set the spatial parameters
-SET_PROP(OnePTestProblem, SpatialParameters)
+SET_PROP(OnePTestProblem, SpatialParams)
 { typedef Dumux::OnePTestSpatialParameters<TypeTag> type; };
 
 // Linear solver settings
diff --git a/test/boxmodels/1p2c/1p2coutflowproblem.hh b/test/boxmodels/1p2c/1p2coutflowproblem.hh
index 7b76d08460aa3ace37776a05a8d773422b716c08..a75cd668e1e5fc3f7e817251ef44949a67a32533 100644
--- a/test/boxmodels/1p2c/1p2coutflowproblem.hh
+++ b/test/boxmodels/1p2c/1p2coutflowproblem.hh
@@ -79,7 +79,7 @@ public:
 
 // Set the spatial parameters
 SET_TYPE_PROP(OnePTwoCOutflowProblem,
-              SpatialParameters,
+              SpatialParams,
               Dumux::OnePTwoCOutflowSpatialParameters<TypeTag>);
 
 //Define whether mole(true) or mass (false) fractions are used
diff --git a/test/boxmodels/2p/lensspatialparameters.hh b/test/boxmodels/2p/lensspatialparameters.hh
index 3a427d784fe990022e2e24b2befb32a79f8ea6a3..d129029bddf46c116f30e191e0e79d6fe0cacca4 100644
--- a/test/boxmodels/2p/lensspatialparameters.hh
+++ b/test/boxmodels/2p/lensspatialparameters.hh
@@ -51,7 +51,7 @@ namespace Properties
 NEW_TYPE_TAG(LensSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(LensSpatialParameters, SpatialParameters, Dumux::LensSpatialParameters<TypeTag>);
+SET_TYPE_PROP(LensSpatialParameters, SpatialParams, Dumux::LensSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(LensSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/2p2c/injectionspatialparameters.hh b/test/boxmodels/2p2c/injectionspatialparameters.hh
index 481b38613093a1c6dfd418f52d5feb13f749eabb..50e34c0126345b0dc562ebb079f6bf2436c3c6fd 100644
--- a/test/boxmodels/2p2c/injectionspatialparameters.hh
+++ b/test/boxmodels/2p2c/injectionspatialparameters.hh
@@ -50,7 +50,7 @@ namespace Properties
 NEW_TYPE_TAG(InjectionSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(InjectionSpatialParameters, SpatialParameters, Dumux::InjectionSpatialParameters<TypeTag>);
+SET_TYPE_PROP(InjectionSpatialParameters, SpatialParams, Dumux::InjectionSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(InjectionSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/2p2cni/waterairspatialparameters.hh b/test/boxmodels/2p2cni/waterairspatialparameters.hh
index fc2a6573006340ce6aecc6a15dff9e48ccc417a4..7083d7da16f3731c51d471c264633e3032fa86c8 100644
--- a/test/boxmodels/2p2cni/waterairspatialparameters.hh
+++ b/test/boxmodels/2p2cni/waterairspatialparameters.hh
@@ -48,7 +48,7 @@ namespace Properties
 NEW_TYPE_TAG(WaterAirSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(WaterAirSpatialParameters, SpatialParameters, Dumux::WaterAirSpatialParameters<TypeTag>);
+SET_TYPE_PROP(WaterAirSpatialParameters, SpatialParams, Dumux::WaterAirSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(WaterAirSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/3p3c/infiltrationspatialparameters.hh b/test/boxmodels/3p3c/infiltrationspatialparameters.hh
index 904dd5a99bd858bb9dc8c1b291d812b42a389c4a..b805aa958bd86348a402b0b44a2cea000ad87616 100644
--- a/test/boxmodels/3p3c/infiltrationspatialparameters.hh
+++ b/test/boxmodels/3p3c/infiltrationspatialparameters.hh
@@ -47,7 +47,7 @@ namespace Properties
 NEW_TYPE_TAG(InfiltrationSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(InfiltrationSpatialParameters, SpatialParameters, Dumux::InfiltrationSpatialParameters<TypeTag>);
+SET_TYPE_PROP(InfiltrationSpatialParameters, SpatialParams, Dumux::InfiltrationSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(InfiltrationSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/3p3cni/columnxylolspatialparameters.hh b/test/boxmodels/3p3cni/columnxylolspatialparameters.hh
index 1d512f9d4feb58e41fbd2d1a58d6fc33ebf9cd55..65e9571df59212b8c81731b88eb57a34c6980152 100644
--- a/test/boxmodels/3p3cni/columnxylolspatialparameters.hh
+++ b/test/boxmodels/3p3cni/columnxylolspatialparameters.hh
@@ -47,7 +47,7 @@ namespace Properties
 NEW_TYPE_TAG(ColumnSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(ColumnSpatialParameters, SpatialParameters, Dumux::ColumnSpatialParameters<TypeTag>);
+SET_TYPE_PROP(ColumnSpatialParameters, SpatialParams, Dumux::ColumnSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(ColumnSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/3p3cni/kuevettespatialparameters.hh b/test/boxmodels/3p3cni/kuevettespatialparameters.hh
index c6c895d34cc3e3dac72fd14be155ad2457c06b38..925955cabe5cf27f89e9003b022d96d225ad0c27 100644
--- a/test/boxmodels/3p3cni/kuevettespatialparameters.hh
+++ b/test/boxmodels/3p3cni/kuevettespatialparameters.hh
@@ -47,7 +47,7 @@ namespace Properties
 NEW_TYPE_TAG(KuevetteSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(KuevetteSpatialParameters, SpatialParameters, Dumux::KuevetteSpatialParameters<TypeTag>);
+SET_TYPE_PROP(KuevetteSpatialParameters, SpatialParams, Dumux::KuevetteSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(KuevetteSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/mpnc/obstaclespatialparameters.hh b/test/boxmodels/mpnc/obstaclespatialparameters.hh
index 84ffac01f74ab0c490c233b59c30c5817bca86f2..4f21f5a73b33e21a987e231868d1ec11be5a4b56 100644
--- a/test/boxmodels/mpnc/obstaclespatialparameters.hh
+++ b/test/boxmodels/mpnc/obstaclespatialparameters.hh
@@ -46,7 +46,7 @@ namespace Properties
 NEW_TYPE_TAG(ObstacleSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(ObstacleSpatialParameters, SpatialParameters, Dumux::ObstacleSpatialParameters<TypeTag>);
+SET_TYPE_PROP(ObstacleSpatialParameters, SpatialParams, Dumux::ObstacleSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(ObstacleSpatialParameters, MaterialLaw)
diff --git a/test/boxmodels/richards/richardslensspatialparameters.hh b/test/boxmodels/richards/richardslensspatialparameters.hh
index e495cabce457a163b2e4a4100b404937cc07dc88..e9321b3f1c72a622a29a307b88c10eab34029a10 100644
--- a/test/boxmodels/richards/richardslensspatialparameters.hh
+++ b/test/boxmodels/richards/richardslensspatialparameters.hh
@@ -50,7 +50,7 @@ namespace Properties
 NEW_TYPE_TAG(RichardsLensSpatialParameters);
 
 // Set the spatial parameters
-SET_TYPE_PROP(RichardsLensSpatialParameters, SpatialParameters, Dumux::RichardsLensSpatialParameters<TypeTag>);
+SET_TYPE_PROP(RichardsLensSpatialParameters, SpatialParams, Dumux::RichardsLensSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(RichardsLensSpatialParameters, MaterialLaw)
diff --git a/test/common/generalproblem/generallensspatialparameters.hh b/test/common/generalproblem/generallensspatialparameters.hh
index 7efa438c9cc35b201c624b48a3cc274ed23e7243..524032f31a250b3bf68c7dbafb47ef88503511b7 100644
--- a/test/common/generalproblem/generallensspatialparameters.hh
+++ b/test/common/generalproblem/generallensspatialparameters.hh
@@ -54,6 +54,7 @@ NEW_PROP_TAG(SpatialParamsBaseClass);
 
 // Set the spatial parameters
 SET_TYPE_PROP(GeneralLensSpatialParameters, SpatialParameters, Dumux::GeneralLensSpatialParameters<TypeTag>);
+SET_TYPE_PROP(GeneralLensSpatialParameters, SpatialParams, Dumux::GeneralLensSpatialParameters<TypeTag>);
 
 // Set the material Law
 SET_PROP(GeneralLensSpatialParameters, MaterialLaw)
diff --git a/tutorial/tutorialspatialparameters_coupled.hh b/tutorial/tutorialspatialparameters_coupled.hh
index 6094e8a0c2ca3510fc0391e96adb7a6811627056..3503de038ac9b0d3df7dd1e31e25cb1d75021846 100644
--- a/tutorial/tutorialspatialparameters_coupled.hh
+++ b/tutorial/tutorialspatialparameters_coupled.hh
@@ -46,7 +46,7 @@ namespace Properties
 NEW_TYPE_TAG(TutorialSpatialParametersCoupled);/*@\label{tutorial-coupled:define-spatialparameters-typetag}@*/
 
 // Set the spatial parameters
-SET_TYPE_PROP(TutorialSpatialParametersCoupled, SpatialParameters,
+SET_TYPE_PROP(TutorialSpatialParametersCoupled, SpatialParams,
         Dumux::TutorialSpatialParametersCoupled<TypeTag>); /*@\label{tutorial-coupled:set-spatialparameters}@*/
 
 // Set the material law
diff --git a/dumux/boxmodels/1p/1pfluxvariables.hh b/dumux/boxmodels/1p/1pfluxvariables.hh
index 2154ad405626fc662afcf8f52e2b6a4c987c1e27..f6a72fbff4862e9b6ec46d3c5d0f8c63d1747ae8 100644
--- a/dumux/boxmodels/1p/1pfluxvariables.hh
+++ b/dumux/boxmodels/1p/1pfluxvariables.hh
@@ -70,16 +70,16 @@ public:
      *
      * \param problem The problem
      * \param element The finite element
      * \param elemGeom The finite-volume geometry in the box scheme
      * \param faceIdx The local index of the SCV (sub-control-volume) face
      * \param elemDat The volume variables of the current element
      */
     OnePFluxVariables(const Problem &problem,
                  const Element &element,
-                 const FVElementGeometry &elemGeom,
+                 const FVElementGeometry &fvGeometry,
                  int faceIdx,
                  const ElementVolumeVariables &elemDat)
-        : fvElemGeom_(elemGeom)
+        : fvGeometry_(fvGeometry)
     {
         scvfIdx_ = faceIdx;
 
@@ -91,7 +91,7 @@ public:
      * \brief The face of the current sub-control volume.
      */
     const SCVFace &face() const
-    { return fvElemGeom_.subContVolFace[scvfIdx_]; }
+    { return fvGeometry_.subContVolFace[scvfIdx_]; }
 
     /*!
      * \brief Return the intrinsic permeability \f$\mathrm{[m^2]}\f$.
@@ -140,7 +140,7 @@ private:
 
         // calculate potential gradient
         for (int idx = 0;
-             idx < fvElemGeom_.numVertices;
+             idx < fvGeometry_.numVertices;
              idx++) // loop over adjacent vertices
         {
             // FE gradient at vertex idx
@@ -158,8 +158,8 @@ private:
         if (GET_PARAM(TypeTag, bool, EnableGravity)) {
             // estimate the gravitational acceleration at a given SCV face
             // using the arithmetic mean
-            Vector g(problem.boxGravity(element, fvElemGeom_, face().i));
-            g += problem.boxGravity(element, fvElemGeom_, face().j);
+            Vector g(problem.boxGravity(element, fvGeometry_, face().i));
+            g += problem.boxGravity(element, fvGeometry_, face().j);
             g /= 2;
 
             // calculate the phase density at the integration point. we
@@ -183,15 +183,15 @@ private:
         const SpatialParameters &spatialParams = problem.spatialParameters();
         spatialParams.meanK(K_,
                             spatialParams.intrinsicPermeability(element,
-                                                                fvElemGeom_,
+                                                                fvGeometry_,
                                                                 face().i),
                             spatialParams.intrinsicPermeability(element,
-                                                                fvElemGeom_,
+                                                                fvGeometry_,
                                                                 face().j));
     }
 
 protected:
-    const FVElementGeometry &fvElemGeom_;
+    const FVElementGeometry &fvGeometry_;
     int scvfIdx_;
 
     // gradients
@@ -70,16 +70,16 @@ public:
      * \param problem The problem
      * \param element The finite element
-     * \param elemGeom The finite-volume geometry in the box scheme
+     * \param fvGeometry The finite-volume geometry in the box scheme
      * \param faceIdx The local index of the SCV (sub-control-volume) face
      * \param elemDat The volume variables of the current element
diff --git a/dumux/boxmodels/2p2c/2p2clocalresidual.hh b/dumux/boxmodels/2p2c/2p2clocalresidual.hh
index e1053a97a64185433da4ab0bfc635a534815b1b5..5bd0ca6a47ee7321815caf4fc645e4fca7d9e463 100644
--- a/dumux/boxmodels/2p2c/2p2clocalresidual.hh
+++ b/dumux/boxmodels/2p2c/2p2clocalresidual.hh
@@ -78,12 +78,12 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
     typedef typename GET_PROP_TYPE(TypeTag, Indices) Indices;
     enum
     {
-        contiLEqIdx = Indices::contiLEqIdx,
-        contiGEqIdx = Indices::contiGEqIdx,
-        lPhaseIdx = Indices::lPhaseIdx,
-        gPhaseIdx = Indices::gPhaseIdx,
-        lCompIdx = Indices::lCompIdx,
-        gCompIdx = Indices::gCompIdx
+        contiWEqIdx = Indices::contiLEqIdx,
+        contiNEqIdx = Indices::contiGEqIdx,
+        wPhaseIdx = Indices::lPhaseIdx,
+        nPhaseIdx = Indices::gPhaseIdx,
+        wCompIdx = Indices::lCompIdx,
+        nCompIdx = Indices::gCompIdx
     };
 
     typedef typename GET_PROP_TYPE(TypeTag, GridView) GridView;
@@ -112,23 +112,23 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      * \param element The element
      * \param phaseIdx The index of the fluid phase
      */
-    void evalPhaseStorage(const Element &element, int phaseIdx)
+    void evalPhaseStorage(const Element &element, const int phaseIdx)
     {
-        FVElementGeometry fvGeom;
-        fvGeom.update(this->gridView_(), element);
+        FVElementGeometry fvGeometry;
+        fvGeometry.update(this->gridView_(), element);
         ElementBoundaryTypes bcTypes;
-        bcTypes.update(this->problem_(), element, fvGeom);
-        ElementVolumeVariables volVars;
-        volVars.update(this->problem_(), element, fvGeom, false);
+        bcTypes.update(this->problem_(), element, fvGeometry);
+        ElementVolumeVariables elemVolVars;
+        elemVolVars.update(this->problem_(), element, fvGeometry, false);
 
-        this->storageTerm_.resize(fvGeom.numVertices);
+        this->storageTerm_.resize(fvGeometry.numVertices);
         this->storageTerm_ = 0;
 
         this->elemPtr_ = &element;
-        this->fvElemGeomPtr_ = &fvGeom;
+        this->fvElemGeomPtr_ = &fvGeometry;
         this->bcTypesPtr_ = &bcTypes;
         this->prevVolVarsPtr_ = 0;
-        this->curVolVarsPtr_ = &volVars;
+        this->curVolVarsPtr_ = &elemVolVars;
         evalPhaseStorage_(phaseIdx);
     }
 
@@ -170,11 +170,11 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      * The result should be averaged over the volume (e.g. phase mass
      * inside a sub-control volume divided by the volume)
      *
-     *  \param result The mass of the component within the sub-control volume
+     *  \param storage The mass of the component within the sub-control volume
      *  \param scvIdx The SCV (sub-control-volume) index
      *  \param usePrevSol Evaluate function with solution of current or previous time step
      */
-    void computeStorage(PrimaryVariables &result, int scvIdx, bool usePrevSol) const
+    void computeStorage(PrimaryVariables &storage, int scvIdx, bool usePrevSol) const
     {
         // if flag usePrevSol is set, the solution from the previous
         // time step is used, otherwise the current solution is
@@ -186,25 +186,25 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
         const VolumeVariables &volVars = elemVolVars[scvIdx];
 
         // compute storage term of all components within all phases
-        result = 0;
+        storage = 0;
 
         for (int phaseIdx = 0; phaseIdx < numPhases; ++phaseIdx)
         {
             for (int compIdx = contiCompIdx1_(); compIdx <= contiCompIdx2_(); ++compIdx)
             {
-                int eqIdx = (compIdx == lCompIdx) ? contiLEqIdx : contiGEqIdx;
-                result[eqIdx] += volVars.density(phaseIdx)
+                int eqIdx = (compIdx == wCompIdx) ? contiWEqIdx : contiNEqIdx;
+                storage[eqIdx] += volVars.density(phaseIdx)
                     * volVars.saturation(phaseIdx)
                     * volVars.fluidState().massFraction(phaseIdx, compIdx);
             }
             // this is only processed, if one component mass balance equation
             // is replaced by the total mass balance equation
             if (replaceCompEqIdx < numComponents)
-                result[replaceCompEqIdx] +=
+                storage[replaceCompEqIdx] +=
                     volVars.density(phaseIdx)
                     * volVars.saturation(phaseIdx);
         }
-        result *= volVars.porosity();
+        storage *= volVars.porosity();
     }
 
     /*!
@@ -217,17 +217,17 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      */
     void computeFlux(PrimaryVariables &flux, int faceIdx, bool onBoundary=false) const
     {
-        FluxVariables vars(this->problem_(),
-                           this->elem_(),
-                           this->fvElemGeom_(),
+        FluxVariables fluxVars(this->problem_(),
+                           this->element_(),
+                           this->fvGeometry_(),
                            faceIdx,
                            this->curVolVars_(),
                            onBoundary);
 
         flux = 0;
-        asImp_()->computeAdvectiveFlux(flux, vars);
+        asImp_()->computeAdvectiveFlux(flux, fluxVars);
         Valgrind::CheckDefined(flux);
-        asImp_()->computeDiffusiveFlux(flux, vars);
+        asImp_()->computeDiffusiveFlux(flux, fluxVars);
         Valgrind::CheckDefined(flux);
     }
 
@@ -236,9 +236,9 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      *        a face of a sub-control volume.
      *
      * \param flux The advective flux over the sub-control-volume face for each component
      * \param vars The flux variables at the current SCV face
      */
-    void computeAdvectiveFlux(PrimaryVariables &flux, const FluxVariables &vars) const
+    void computeAdvectiveFlux(PrimaryVariables &flux, const FluxVariables &fluxVars) const
     {
         ////////
         // advective fluxes of all components in all phases
@@ -248,19 +248,19 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
             // data attached to upstream and the downstream vertices
             // of the current phase
             const VolumeVariables &up =
-                this->curVolVars_(vars.upstreamIdx(phaseIdx));
+                this->curVolVars_(fluxVars.upstreamIdx(phaseIdx));
             const VolumeVariables &dn =
-                this->curVolVars_(vars.downstreamIdx(phaseIdx));
+                this->curVolVars_(fluxVars.downstreamIdx(phaseIdx));
 
             for (int compIdx = contiCompIdx1_(); compIdx <= contiCompIdx2_(); ++compIdx)
             {
-                int eqIdx = (compIdx == lCompIdx) ? contiLEqIdx : contiGEqIdx;
+                int eqIdx = (compIdx == wCompIdx) ? contiWEqIdx : contiNEqIdx;
                 // add advective flux of current component in current
                 // phase
                 if (massUpwindWeight_ > 0.0)
                     // upstream vertex
                     flux[eqIdx] +=
-                        vars.KmvpNormal(phaseIdx)
+                        fluxVars.KmvpNormal(phaseIdx)
                         * massUpwindWeight_
                         * up.density(phaseIdx)
                         * up.mobility(phaseIdx)
@@ -268,13 +268,13 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
                 if (massUpwindWeight_ < 1.0)
                     // downstream vertex
                     flux[eqIdx] +=
-                        vars.KmvpNormal(phaseIdx)
+                        fluxVars.KmvpNormal(phaseIdx)
                         * (1 - massUpwindWeight_)
                         * dn.density(phaseIdx)
                         * dn.mobility(phaseIdx)
                         * dn.fluidState().massFraction(phaseIdx, compIdx);
 
-                Valgrind::CheckDefined(vars.KmvpNormal(phaseIdx));
+                Valgrind::CheckDefined(fluxVars.KmvpNormal(phaseIdx));
                 Valgrind::CheckDefined(up.density(phaseIdx));
                 Valgrind::CheckDefined(up.mobility(phaseIdx));
                 Valgrind::CheckDefined(up.fluidState().massFraction(phaseIdx, compIdx));
@@ -290,18 +290,18 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
                 // upstream vertex
                 if (massUpwindWeight_ > 0.0)
                     flux[replaceCompEqIdx] +=
-                        vars.KmvpNormal(phaseIdx)
+                        fluxVars.KmvpNormal(phaseIdx)
                         * massUpwindWeight_
                         * up.density(phaseIdx)
                         * up.mobility(phaseIdx);
                 // downstream vertex
                 if (massUpwindWeight_ < 1.0)
                     flux[replaceCompEqIdx] +=
-                        vars.KmvpNormal(phaseIdx)
+                        fluxVars.KmvpNormal(phaseIdx)
                         * (1 - massUpwindWeight_)
                         * dn.density(phaseIdx)
                         * dn.mobility(phaseIdx);
-                Valgrind::CheckDefined(vars.KmvpNormal(phaseIdx));
+                Valgrind::CheckDefined(fluxVars.KmvpNormal(phaseIdx));
                 Valgrind::CheckDefined(up.density(phaseIdx));
                 Valgrind::CheckDefined(up.mobility(phaseIdx));
                 Valgrind::CheckDefined(dn.density(phaseIdx));
@@ -317,47 +317,47 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      *        a face of a sub-control volume.
      *
      * \param flux The diffusive flux over the sub-control-volume face for each component
      * \param vars The flux variables at the current sub control volume face
      */
-    void computeDiffusiveFlux(PrimaryVariables &flux, const FluxVariables &vars) const
+    void computeDiffusiveFlux(PrimaryVariables &flux, const FluxVariables &fluxVars) const
     {
         // add diffusive flux of gas component in liquid phase
-        Scalar tmp = vars.molarConcGrad(lPhaseIdx)*vars.face().normal;
+        Scalar tmp = fluxVars.moleFractionGrad(wPhaseIdx)*fluxVars.face().normal;
         tmp *= -1;
         tmp *=
-            vars.porousDiffCoeff(lPhaseIdx) *
-            vars.molarDensityAtIP(lPhaseIdx);
+            fluxVars.porousDiffCoeff(wPhaseIdx) *
+            fluxVars.molarDensity(wPhaseIdx);
         // add the diffusive fluxes only to the component mass balance
-        if (replaceCompEqIdx != contiGEqIdx)
-            flux[contiGEqIdx] += tmp * FluidSystem::molarMass(gCompIdx);
-        if (replaceCompEqIdx != contiLEqIdx)
-            flux[contiLEqIdx] -= tmp * FluidSystem::molarMass(lCompIdx);
+        if (replaceCompEqIdx != contiNEqIdx)
+            flux[contiNEqIdx] += tmp * FluidSystem::molarMass(nCompIdx);
+        if (replaceCompEqIdx != contiWEqIdx)
+            flux[contiWEqIdx] -= tmp * FluidSystem::molarMass(wCompIdx);
 
         // add diffusive flux of liquid component in gas phase
-        tmp = vars.molarConcGrad(gPhaseIdx)*vars.face().normal;
+        tmp = fluxVars.moleFractionGrad(nPhaseIdx)*fluxVars.face().normal;
         tmp *= -1;
         tmp *=
-            vars.porousDiffCoeff(gPhaseIdx) *
-            vars.molarDensityAtIP(gPhaseIdx);
+            fluxVars.porousDiffCoeff(nPhaseIdx) *
+            fluxVars.molarDensity(nPhaseIdx);
         // add the diffusive fluxes only to the component mass balance
-        if (replaceCompEqIdx != contiLEqIdx)
-            flux[contiLEqIdx] += tmp * FluidSystem::molarMass(lCompIdx);
-        if (replaceCompEqIdx != contiGEqIdx)
-            flux[contiGEqIdx] -= tmp * FluidSystem::molarMass(gCompIdx);
+        if (replaceCompEqIdx != contiWEqIdx)
+            flux[contiWEqIdx] += tmp * FluidSystem::molarMass(wCompIdx);
+        if (replaceCompEqIdx != contiNEqIdx)
+            flux[contiNEqIdx] -= tmp * FluidSystem::molarMass(nCompIdx);
     }
 
     /*!
      * \brief Calculate the source term of the equation
      *
-     * \param q The source/sink in the sub-control volume for each component
-     * \param localVertexIdx The index of the sub-control volume
+     * \param source The source/sink in the sub-control volume for each component
+     * \param scvIdx The index of the sub-control volume
      */
-    void computeSource(PrimaryVariables &q, int localVertexIdx)
+    void computeSource(PrimaryVariables& source, int scvIdx)
     {
-        this->problem_().boxSDSource(q,
-                                     this->elem_(),
-                                     this->fvElemGeom_(),
-                                     localVertexIdx,
+        this->problem_().boxSDSource(source,
+                                     this->element_(),
+                                     this->fvGeometry_(),
+                                     scvIdx,
                                      this->curVolVars_());
     }
 
@@ -365,23 +365,23 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
     void evalPhaseStorage_(int phaseIdx)
     {
         // evaluate the storage terms of a single phase
-        for (int i=0; i < this->fvElemGeom_().numVertices; i++) {
-            PrimaryVariables &result = this->storageTerm_[i];
+        for (int i=0; i < this->fvGeometry_().numVertices; i++) {
+            PrimaryVariables &storage = this->storageTerm_[i];
             const ElementVolumeVariables &elemVolVars = this->curVolVars_();
             const VolumeVariables &volVars = elemVolVars[i];
 
             // compute storage term of all components within all phases
-            result = 0;
+            storage = 0;
             for (int compIdx = 0; compIdx < numComponents; ++compIdx)
             {
-                int eqIdx = (compIdx == lCompIdx) ? contiLEqIdx : contiGEqIdx;
-                result[eqIdx] += volVars.density(phaseIdx)
+                int eqIdx = (compIdx == wCompIdx) ? contiWEqIdx : contiNEqIdx;
+                storage[eqIdx] += volVars.density(phaseIdx)
                     * volVars.saturation(phaseIdx)
                     * volVars.fluidState().massFraction(phaseIdx, compIdx);
             }
 
-            result *= volVars.porosity();
-            result *= this->fvElemGeom_().subContVol[i].volume;
+            storage *= volVars.porosity();
+            storage *= this->fvGeometry_().subContVol[i].volume;
         }
     }
 
@@ -394,8 +394,8 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
     constexpr unsigned int contiCompIdx1_() const {
         switch (replaceCompEqIdx)
         {
-        case contiLEqIdx: return contiGEqIdx;
-        case contiGEqIdx: return contiLEqIdx;
+        case contiWEqIdx: return contiNEqIdx;
+        case contiNEqIdx: return contiWEqIdx;
         default:          return 0;
         }
     }
@@ -409,8 +409,8 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
     constexpr unsigned int contiCompIdx2_() const {
         switch (replaceCompEqIdx)
         {
-        case contiLEqIdx: return contiGEqIdx;
-        case contiGEqIdx: return contiLEqIdx;
+        case contiWEqIdx: return contiNEqIdx;
+        case contiNEqIdx: return contiWEqIdx;
         default:          return numComponents-1;
         }
     }
@@ -236,9 +236,9 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      *
      * \param flux The advective flux over the sub-control-volume face for each component
-     * \param vars The flux variables at the current SCV face
+     * \param fluxVars The flux variables at the current SCV face
      */
@@ -317,47 +317,47 @@ class TwoPTwoCLocalResidual: public GET_PROP_TYPE(TypeTag, BaseLocalResidual)
      *
      * \param flux The diffusive flux over the sub-control-volume face for each component
-     * \param vars The flux variables at the current sub control volume face
+     * \param fluxVars The flux variables at the current sub control volume face
      */